<?php
/*
Plugin Name: Purchase Log Notification Included Tax 

Description: Allow display of tax included in emails to customers, admin.  Use %incl_tax% tag.  Use with care!
Version: 0.2
Author: dom.latter@whitelamp.com
Author URI: http://whitelamp.com/
*/

/*
 This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public 
 License as published by the Free Software Foundation, version 2.
 This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied 
 warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
 */

// Rationale: in some countries, although prices must be displayed inclusive of VAT (sales tax), the 
// customer receipt must show how much tax has been paid.  This plugin allows the use of the %incl_tax%
// tag in the customer notification email (which is set up in the admin interface).
// Additionally it adds a line to the admin notification email (which is hard-coded) with the same
// info.

// Caveats: this doesn't account for any tax on shipping; nor for discounts, coupons, additional tax 
// or anything else.  But if you are running a nice simple shop it should work.
// The tax gets added up twice over, once for each email, but there doesn't seem to be a simple
// solution to that - and you'll probably find the filters being run more than once anyway.

// If you'd like this plugin modified to allow additional tags then please contact the author.

function purchase_log_add_up_included_tax($pln)
{
    $pl = $pln->get_purchase_log();
    $gwdata = $pl->get_gateway_data();
    $tax_included = 0;
    foreach ($gwdata['items'] as $item) {
        if (isset($item['tax'])) {
            $tax_included += $item['tax'];
        }
    }
    return wpsc_currency_display( $tax_included, array( 'display_as_html' => false ) );
}

add_filter( 'wpsc_purchase_log_notification_common_args', 'purchase_log_notification_included_tax', 10, 2);

function purchase_log_notification_included_tax($args, $pln)
{
    $args['incl_tax'] = purchase_log_add_up_included_tax($pln);
    return ($args);
}

add_filter( 'wpsc_purchase_log_admin_notification_raw_message', 'purchase_log_admin_notification_included_tax', 10, 2);

function purchase_log_admin_notification_included_tax($msg, $pln)
{
    $incl_tax = purchase_log_add_up_included_tax($pln);
    $msg .= "Included tax: ".$incl_tax."\r\n";
    return ($msg);
}